// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: imagegeom.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_imagegeom_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_imagegeom_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3015000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3015003 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_imagegeom_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_imagegeom_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
extern GZ_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_imagegeom_2eproto;
GZ_MSGS_VISIBLE ::PROTOBUF_NAMESPACE_ID::Metadata descriptor_table_imagegeom_2eproto_metadata_getter(int index);
namespace gazebo {
namespace msgs {
class ImageGeom;
struct ImageGeomDefaultTypeInternal;
GZ_MSGS_VISIBLE extern ImageGeomDefaultTypeInternal _ImageGeom_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::ImageGeom* Arena::CreateMaybeMessage<::gazebo::msgs::ImageGeom>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE ImageGeom PROTOBUF_FINAL :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.ImageGeom) */ {
 public:
  inline ImageGeom() : ImageGeom(nullptr) {}
  virtual ~ImageGeom();
  explicit constexpr ImageGeom(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  ImageGeom(const ImageGeom& from);
  ImageGeom(ImageGeom&& from) noexcept
    : ImageGeom() {
    *this = ::std::move(from);
  }

  inline ImageGeom& operator=(const ImageGeom& from) {
    CopyFrom(from);
    return *this;
  }
  inline ImageGeom& operator=(ImageGeom&& from) noexcept {
    if (GetArena() == from.GetArena()) {
      if (this != &from) InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return GetMetadataStatic().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return GetMetadataStatic().reflection;
  }
  static const ImageGeom& default_instance() {
    return *internal_default_instance();
  }
  static inline const ImageGeom* internal_default_instance() {
    return reinterpret_cast<const ImageGeom*>(
               &_ImageGeom_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(ImageGeom& a, ImageGeom& b) {
    a.Swap(&b);
  }
  inline void Swap(ImageGeom* other) {
    if (other == this) return;
    if (GetArena() == other->GetArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ImageGeom* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline ImageGeom* New() const final {
    return CreateMaybeMessage<ImageGeom>(nullptr);
  }

  ImageGeom* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<ImageGeom>(arena);
  }
  void CopyFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void MergeFrom(const ::PROTOBUF_NAMESPACE_ID::Message& from) final;
  void CopyFrom(const ImageGeom& from);
  void MergeFrom(const ImageGeom& from);
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  inline void SharedCtor();
  inline void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(ImageGeom* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.ImageGeom";
  }
  protected:
  explicit ImageGeom(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;
  private:
  static ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadataStatic() {
    return ::descriptor_table_imagegeom_2eproto_metadata_getter(kIndexInFileMessages);
  }

  public:

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kUriFieldNumber = 1,
    kScaleFieldNumber = 2,
    kHeightFieldNumber = 4,
    kGranularityFieldNumber = 5,
    kThresholdFieldNumber = 3,
  };
  // required string uri = 1;
  bool has_uri() const;
  private:
  bool _internal_has_uri() const;
  public:
  void clear_uri();
  const std::string& uri() const;
  void set_uri(const std::string& value);
  void set_uri(std::string&& value);
  void set_uri(const char* value);
  void set_uri(const char* value, size_t size);
  std::string* mutable_uri();
  std::string* release_uri();
  void set_allocated_uri(std::string* uri);
  private:
  const std::string& _internal_uri() const;
  void _internal_set_uri(const std::string& value);
  std::string* _internal_mutable_uri();
  public:

  // optional double scale = 2;
  bool has_scale() const;
  private:
  bool _internal_has_scale() const;
  public:
  void clear_scale();
  double scale() const;
  void set_scale(double value);
  private:
  double _internal_scale() const;
  void _internal_set_scale(double value);
  public:

  // optional double height = 4;
  bool has_height() const;
  private:
  bool _internal_has_height() const;
  public:
  void clear_height();
  double height() const;
  void set_height(double value);
  private:
  double _internal_height() const;
  void _internal_set_height(double value);
  public:

  // optional int32 granularity = 5;
  bool has_granularity() const;
  private:
  bool _internal_has_granularity() const;
  public:
  void clear_granularity();
  ::PROTOBUF_NAMESPACE_ID::int32 granularity() const;
  void set_granularity(::PROTOBUF_NAMESPACE_ID::int32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::int32 _internal_granularity() const;
  void _internal_set_granularity(::PROTOBUF_NAMESPACE_ID::int32 value);
  public:

  // optional int32 threshold = 3 [default = 255];
  bool has_threshold() const;
  private:
  bool _internal_has_threshold() const;
  public:
  void clear_threshold();
  ::PROTOBUF_NAMESPACE_ID::int32 threshold() const;
  void set_threshold(::PROTOBUF_NAMESPACE_ID::int32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::int32 _internal_threshold() const;
  void _internal_set_threshold(::PROTOBUF_NAMESPACE_ID::int32 value);
  public:

  // @@protoc_insertion_point(class_scope:gazebo.msgs.ImageGeom)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr uri_;
  double scale_;
  double height_;
  ::PROTOBUF_NAMESPACE_ID::int32 granularity_;
  ::PROTOBUF_NAMESPACE_ID::int32 threshold_;
  friend struct ::TableStruct_imagegeom_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// ImageGeom

// required string uri = 1;
inline bool ImageGeom::_internal_has_uri() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  return value;
}
inline bool ImageGeom::has_uri() const {
  return _internal_has_uri();
}
inline void ImageGeom::clear_uri() {
  uri_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000001u;
}
inline const std::string& ImageGeom::uri() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.ImageGeom.uri)
  return _internal_uri();
}
inline void ImageGeom::set_uri(const std::string& value) {
  _internal_set_uri(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.ImageGeom.uri)
}
inline std::string* ImageGeom::mutable_uri() {
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.ImageGeom.uri)
  return _internal_mutable_uri();
}
inline const std::string& ImageGeom::_internal_uri() const {
  return uri_.Get();
}
inline void ImageGeom::_internal_set_uri(const std::string& value) {
  _has_bits_[0] |= 0x00000001u;
  uri_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArena());
}
inline void ImageGeom::set_uri(std::string&& value) {
  _has_bits_[0] |= 0x00000001u;
  uri_.Set(
    ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, ::std::move(value), GetArena());
  // @@protoc_insertion_point(field_set_rvalue:gazebo.msgs.ImageGeom.uri)
}
inline void ImageGeom::set_uri(const char* value) {
  GOOGLE_DCHECK(value != nullptr);
  _has_bits_[0] |= 0x00000001u;
  uri_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, ::std::string(value), GetArena());
  // @@protoc_insertion_point(field_set_char:gazebo.msgs.ImageGeom.uri)
}
inline void ImageGeom::set_uri(const char* value,
    size_t size) {
  _has_bits_[0] |= 0x00000001u;
  uri_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, ::std::string(
      reinterpret_cast<const char*>(value), size), GetArena());
  // @@protoc_insertion_point(field_set_pointer:gazebo.msgs.ImageGeom.uri)
}
inline std::string* ImageGeom::_internal_mutable_uri() {
  _has_bits_[0] |= 0x00000001u;
  return uri_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArena());
}
inline std::string* ImageGeom::release_uri() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.ImageGeom.uri)
  if (!_internal_has_uri()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000001u;
  return uri_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArena());
}
inline void ImageGeom::set_allocated_uri(std::string* uri) {
  if (uri != nullptr) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  uri_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), uri,
      GetArena());
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.ImageGeom.uri)
}

// optional double scale = 2;
inline bool ImageGeom::_internal_has_scale() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  return value;
}
inline bool ImageGeom::has_scale() const {
  return _internal_has_scale();
}
inline void ImageGeom::clear_scale() {
  scale_ = 0;
  _has_bits_[0] &= ~0x00000002u;
}
inline double ImageGeom::_internal_scale() const {
  return scale_;
}
inline double ImageGeom::scale() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.ImageGeom.scale)
  return _internal_scale();
}
inline void ImageGeom::_internal_set_scale(double value) {
  _has_bits_[0] |= 0x00000002u;
  scale_ = value;
}
inline void ImageGeom::set_scale(double value) {
  _internal_set_scale(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.ImageGeom.scale)
}

// optional int32 threshold = 3 [default = 255];
inline bool ImageGeom::_internal_has_threshold() const {
  bool value = (_has_bits_[0] & 0x00000010u) != 0;
  return value;
}
inline bool ImageGeom::has_threshold() const {
  return _internal_has_threshold();
}
inline void ImageGeom::clear_threshold() {
  threshold_ = 255;
  _has_bits_[0] &= ~0x00000010u;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 ImageGeom::_internal_threshold() const {
  return threshold_;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 ImageGeom::threshold() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.ImageGeom.threshold)
  return _internal_threshold();
}
inline void ImageGeom::_internal_set_threshold(::PROTOBUF_NAMESPACE_ID::int32 value) {
  _has_bits_[0] |= 0x00000010u;
  threshold_ = value;
}
inline void ImageGeom::set_threshold(::PROTOBUF_NAMESPACE_ID::int32 value) {
  _internal_set_threshold(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.ImageGeom.threshold)
}

// optional double height = 4;
inline bool ImageGeom::_internal_has_height() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool ImageGeom::has_height() const {
  return _internal_has_height();
}
inline void ImageGeom::clear_height() {
  height_ = 0;
  _has_bits_[0] &= ~0x00000004u;
}
inline double ImageGeom::_internal_height() const {
  return height_;
}
inline double ImageGeom::height() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.ImageGeom.height)
  return _internal_height();
}
inline void ImageGeom::_internal_set_height(double value) {
  _has_bits_[0] |= 0x00000004u;
  height_ = value;
}
inline void ImageGeom::set_height(double value) {
  _internal_set_height(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.ImageGeom.height)
}

// optional int32 granularity = 5;
inline bool ImageGeom::_internal_has_granularity() const {
  bool value = (_has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool ImageGeom::has_granularity() const {
  return _internal_has_granularity();
}
inline void ImageGeom::clear_granularity() {
  granularity_ = 0;
  _has_bits_[0] &= ~0x00000008u;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 ImageGeom::_internal_granularity() const {
  return granularity_;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 ImageGeom::granularity() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.ImageGeom.granularity)
  return _internal_granularity();
}
inline void ImageGeom::_internal_set_granularity(::PROTOBUF_NAMESPACE_ID::int32 value) {
  _has_bits_[0] |= 0x00000008u;
  granularity_ = value;
}
inline void ImageGeom::set_granularity(::PROTOBUF_NAMESPACE_ID::int32 value) {
  _internal_set_granularity(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.ImageGeom.granularity)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef boost::shared_ptr<gazebo::msgs::ImageGeom> ImageGeomPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::ImageGeom const> ConstImageGeomPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_imagegeom_2eproto
